@@ -44,9 +44,7 @@ class O365Account(Account):
             'scopes': scopes,
             'auth_flow_type': auth_flow_type
         }
-        print(f"{scopes=}")
         super().__init__(creds, **OPTIONS)
-        print(f"{self.is_authenticated=}")
         if not self.is_authenticated:
             self.authenticate()
         self.drives = self.storage().get_drives()
@@ -80,7 +78,6 @@ class O365Account(Account):
         results = list(drive.search(query))
         return results[0] if results else results
 
-
     def get_folder(self, *subfolders: str, site: str = None):
         if len(subfolders) == 0:
             return self.drive
@@ -96,3 +93,8 @@ class O365Account(Account):
             except:
                 raise ('Path {} not exist.'.format('/'.join(subfolders)))
         return subfolder_drive
+
+    def get_document_library_by_name(self, document_library_name: str):
+        for drive in self.site.list_document_libraries():
+            if drive.name.lower() == document_library_name.lower():
+                return drive
\ No newline at end of file
